%{!?kernel_version: %{expand: %%define kernel_version %(uname -r|sed -e 's/EL.*$/EL/g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | sed -e 's/.*EL//g' | sed -e 's/^$/up/g')}}

# On RHEL 3, up type has no tag
%if "%{type}" != "up"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%endif

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vmci'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,rhel,3
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vmci/vmware-pmwv.pl --os=linux,rhel,3 --release %{kernel_dir} --rpmBuild 1310128 --modKey %{modKey}
%define kmp_version %version

Name:         vmware-tools-vmci
BuildRequires: kernel-source gcc
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmci kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.0.15.0
Release:      4.el3
BuildRoot:    %{_tmppath}/%{name}-%{version}-build
Source1:      vmci-configModule.tar.gz

Source0:      vmci.tar

%prep
%setup -n vmci-only

%build
make clean
make

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
# The following command copies our newly build kernel module to a known
# location.  Unfortunately sometimes the kmod source build places the kmods
# in inconsistent locations.
if [ -e ../vmci.o ]; then
   cp -v ../vmci.o .
fi
if [ -e driver-%{kernel_dir}/vmci-xxx-%{kernel_dir} ]; then
   cp -v driver-%{kernel_dir}/vmci-xxx-%{kernel_dir} ./vmci.o
fi

# Install kernel module
install -m 644 -D vmci.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/%{name}/vmci.o

# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmci.  The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%package common
Summary:      Contains the common files used by all the vmci kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      4.el3
Version:      8.6.11

%description common
 This package contains the common system configuration and scripts responsible for loading the vmci kernel module.  The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%package kmp-%{type}
Summary:      The vmci kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vmci-common
Requires:     vmware-tools-foundation >= 0:8.6.0
Provides:     vmware-tools-vmci-kmp
Release:      %{kversionreltag}.4.el3


%description kmp-%{type}
 This package contains a pre-compiled vmci module for use with the %{kernel_version} kernel.   The vmci device is a virtual PCI device that provides high-speed communication between the virtual machine and its hypervisor or host applications as well as between virtual machines that reside on the same host. Vmci does not rely on guest networking.

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmci stop
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%pre common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmci ]; then
      /sbin/chkconfig vmci off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl --os=linux,rhel,3 --toDeconfigure=vmci
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,rhel,3 --dbDelAnswer VMCI_NAME
fi

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmci ]; then
      /sbin/chkconfig vmci off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl --os=linux,rhel,3 --toDeconfigure=vmci
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,rhel,3 --dbDelAnswer VMCI_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,rhel,3 --dbAddAnswer VMCI_NAME,vmci
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-config.pl --os=linux,rhel,3 --toConfigure=vmci
if [ -e /etc/init.d/vmci ]; then
   /sbin/chkconfig vmci on
fi

%post kmp-%{type}
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/%{name}/vmci.o

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*EL//g'`
if [ -z "$kmodType" ]; then
   kmodType=up
fi
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vmci start
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmci ]; then
      /sbin/chkconfig vmci off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl --os=linux,rhel,3 --toDeconfigure=vmci
   /usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl --os=linux,rhel,3 --dbDelAnswer VMCI_NAME
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmci stop
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmci/vmware-config.pl
/etc/rc.d/init.d/vmci

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/%{name}/vmci.o
